@@ -1,9 +1,12 @@
 from __future__ import annotations
 
+import os
 from typing import TYPE_CHECKING
 
 import click
 
+from hatch.config.constants import AppEnvVars
+
 if TYPE_CHECKING:
     from hatch.cli.application import Application
 
@@ -135,6 +138,7 @@ def run(
         environments,
         ignore_compat=ignore_compat or matrix_selected,
         display_header=matrix_selected,
+        keep_env=bool(os.environ.get(AppEnvVars.KEEP_ENV)),
     ):
         if context.env.name == "system":
             context.env.exists = lambda: True  # type: ignore[method-assign]
